@@ -25,13 +25,9 @@
 """
 Main Entry Point
 """
-import os
-import signal
-
 import connexion
 import prometheus_client
 import waitress
-from flask import jsonify
 
 from fabric_cm.credmgr.swagger_server import encoder
 from fabric_cm.credmgr.config import CONFIG_OBJ
@@ -63,11 +59,6 @@ def main():
         log.error(ex)
         raise ex
 
-    @app.route('/stopServer', methods=['GET'])
-    def stop_server():
-        os.kill(os.getpid(), signal.SIGINT)
-        return jsonify({"success": True, "message": "Server is shutting down..."})
-
 
 if __name__ == '__main__':
     main()
